use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Brocard
Chia
Ishigaki
Kao
Kenichi
Kojima
Leon
Mechanize
Olaf
PSGI
Shin
Sośnierz
Tadeusz
Test
UserAgent
WWW
acme
clkao
ishigaki
lib
maxlength
moznion
olaf
params
shin
spidering
tadeusz
tokuhirom
